#!/usr/bin/env python
# -*- mode:python; tab-width: 2; coding: utf-8 -*-

"""
Logging module for sleipnir

log provides extensions to the current logging facility provided by
Python. Use 'log' instance from module to invoke an appropiate log
facility to the module in use.

To use, simply 'import log' and use 'log instance
"""

from __future__ import absolute_import

__author__  = "Ju Jie Lin <livibetter(at)gmail.com>"
__status__  = "production"
__version__ = "1.0"
__date__    = "26 February 2009"

import sys
import __builtin__

# For Python 2.5-, this will enable the simliar property mechanism as in
# Python 2.6+/3.0+. The code is based on
# http://bruynooghe.blogspot.com/2008/04/xsetter-syntax-in-python-25.html
if sys.version_info[:2] <= (2, 5):
    # If you need to access original built-in propery,
    # uncomment the next line
    # __builtin__._property = property

    class property(property):
        """A replacement for builtin property"""

        def __init__(self, fget, *args, **kwargs):
            self.__doc__ = fget.__doc__
            super(property, self).__init__(fget, *args, **kwargs)

        def setter(self, fset):
            """Descriptor to change the setter on a property"""
            cls_ns = sys._getframe(1).f_locals
            for k, v in cls_ns.iteritems():
                if v == self:
                    propname = k
                    break
            cls_ns[propname] = property(
              self.fget, fset, self.fdel, self.__doc__)
            return cls_ns[propname]

        def deleter(self, fdel):
            """Descriptor to change the deletter on a property"""
            cls_ns = sys._getframe(1).f_locals
            for k, v in cls_ns.iteritems():
                if v == self:
                    propname = k
                    break
            cls_ns[propname] = property(
              self.fget, self.fset, fdel, self.__doc__)
            return cls_ns[propname]

    __builtin__.property = property
